aboutsummaryrefslogtreecommitdiff
path: root/checkmem.s
diff options
context:
space:
mode:
Diffstat (limited to 'checkmem.s')
-rw-r--r--checkmem.s6
1 files changed, 3 insertions, 3 deletions
diff --git a/checkmem.s b/checkmem.s
index 9994add..a539e4b 100644
--- a/checkmem.s
+++ b/checkmem.s
@@ -101,11 +101,11 @@ gr_0:
; save display list pointer where taipan.c's main() can find it.
; this is done ASAP after the CIO call, to avoid saving the DL
; after SpartaDOS's TDLINE has had a chance to modify it.
; we use FR1 because the menu code in newtitle.s trashes FR0.
lda SDLSTL
- sta FR1
+ sta FRE
lda SDLSTH
- sta FR1+1
+ sta FRE+1
rts
@@ -101,11 +101,11 @@ gr_0:
; this is done ASAP after the CIO call, to avoid saving the DL
; after SpartaDOS's TDLINE has had a chance to modify it.
- ; we use FR1 because the menu code in newtitle.s trashes FR0.
+ ; we use FRE because the menu code in newtitle.s trashes FR0 and FR1.
lda SDLSTL